@@ -106,7 +106,7 @@ static int _compareByName(id obj1, id obj2, void * context);
 }
 
 // Is equal only if same name; used to make aliasing ordering stable
-- (unsigned)hash {
+- (NSUInteger)hash {
   return [name hash];
 }
 
@@ -1100,11 +1100,7 @@ static inline void _addToPropList(NSMutableDictionary *propertyList,
     unsigned cnt, cnt2;
 
     clen = [self cStringLength];
-#if GNU_RUNTIME
-    s = objc_atomic_malloc(clen + 4);
-#else
     s = malloc(clen + 4);
-#endif
 
     [self getCString:s maxLength:clen];
     
