@@ -37,18 +37,6 @@
 #include <NGMime/NGMime.h>
 #include <NGMail/NGMail.h>
 
-#if NeXT_RUNTIME || APPLE_RUNTIME
-#  ifndef sel_eq
-#    define sel_eq(__A__,__B__) (__A__==__B__)
-#  endif
-#endif
-
-#if __GNU_LIBOBJC__ >= 20100911
-#  ifndef sel_eq
-#    define sel_eq(__A__,__B__) sel_isEqual(__A__,__B__)
-#  endif
-#endif
-
 @interface NSObject(NGImap4_OSXHacks)
 - (void)subclassResponsibility:(SEL)_acmd;
 - (void)notImplemented:(SEL)_acmd;
